@@ -1,7 +1,7 @@
 package Dist::Zilla::PluginBundle::ARODLAND;
 # ABSTRACT: Use L<Dist::Zilla> like ARODLAND does
 our $AUTHORITY = 'cpan:ARODLAND'; # AUTHORITY
-our $VERSION = '0.13'; # VERSION
+our $VERSION = '0.14'; # VERSION
 
 use 5.10.0;
 use Moose;
@@ -224,8 +224,9 @@ sub bundle_config {
           ? (tag_message => $tag_message)
           : ()
         ),
-        allow_dirty => ['dist.ini', 'README', 'README.pod', 'Changes'],
+        allow_dirty => ['dist.ini', 'README', 'README.pod', 'META.json', 'Changes'],
         changelog => 'Changes',
+        add_files_in => ['README', 'README.pod', 'META.json'],
         commit_msg => 'Release v%v%n%n%c',
         push_to => 'origin',
       },
@@ -248,7 +249,7 @@ Dist::Zilla::PluginBundle::ARODLAND - Use L<Dist::Zilla> like ARODLAND does
 
 =head1 VERSION
 
-version 0.13
+version 0.14
 
 =head1 DESCRIPTION
 
